@@ -11,5 +11,11 @@ def get_gauss_random_num(min_value, max_value):
     mu = (min_value + max_value) / 2
     sigma = (max_value - mu) / 3
     s = random.gauss(mu, sigma)
-    return int(s)
+    value = int(s)
+    if value < min_value:
+        return min_value
+    if max_value > max_value:
+        return max_value
+
+    return value
 
